from setuptools import setup

setup(
    name='rova_afval',
    packages=['rova_afval'],
    version='0.4',
    description='ROVA Afvalkalender API',
    author='M. Lowijs',
    author_email='mlowijs@gmail.com',
    url='https://github.com/mlowijs/rova_afval',
    download_url='https://github.com/mlowijs/rova_afval/archive/0.4.tar.gz',
    keywords=['rova', 'afval'],
    classifiers=[]
)
